var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _interopRequireWildcard2 = _interopRequireDefault(require("@babel/runtime/helpers/interopRequireWildcard"));

var _plugin = _interopRequireDefault(require("@start/plugin"));

var _default = (inDir, outDir) => (0, _plugin.default)('typescriptGenerate', ({
  logPath
}) => async () => {
  const path = await Promise.resolve().then(() => (0, _interopRequireWildcard2.default)(require('path')));
  const ts = await Promise.resolve().then(() => (0, _interopRequireWildcard2.default)(require('typescript')));
  const inDirFull = path.resolve(inDir);
  const outDirFull = path.resolve(outDir);

  const inFile = require.resolve(inDirFull);

  const configPath = ts.findConfigFile(inDirFull, ts.sys.fileExists);

  if (typeof configPath === 'undefined') {
    throw new Error(`Unable to find \`tsconfig.json\` for ${inDir}`);
  }

  const configFile = ts.readConfigFile(configPath, ts.sys.readFile);
  const parsedConfig = ts.parseJsonConfigFileContent(configFile.config, ts.sys, path.dirname(configPath));
  const options = { ...parsedConfig.options,
    noEmit: false,
    emitDeclarationOnly: true,
    declarationDir: outDirFull,
    declaration: true
  };

  if (!(inFile.endsWith('.ts') || inFile.endsWith('.tsx')) && !options.allowJs) {
    return;
  }

  const program = ts.createProgram([inFile], options);
  const emitResult = program.emit();
  logPath(inFile);
  const allDiagnostics = ts.getPreEmitDiagnostics(program).concat(emitResult.diagnostics);

  for (const diagnostic of allDiagnostics) {
    if (typeof diagnostic.file === 'undefined') {
      console.log(`${ts.flattenDiagnosticMessageText(diagnostic.messageText, '\n')}`);
      continue;
    }

    const {
      line,
      character
    } = diagnostic.file.getLineAndCharacterOfPosition(diagnostic.start);
    const message = ts.flattenDiagnosticMessageText(diagnostic.messageText, '\n');
    console.log(`${diagnostic.file.fileName} (${line + 1},${character + 1}): ${message}`);
  }
});

exports.default = _default;